Changelog
=========

v0.0.3
------

- Collect binary symbols from ELF binaries using BIDS
  https://pypi.org/project/bids-analyser/0.2.0/
  Also make this available in the scancode-toolkit plugin ``--elf``.

v0.0.2
------

- Update link references of ownership from nexB to aboutcode-org

v0.0.1
------

Initial release with basic support to collect
 - DWARF debug sections compilation unit paths.
 - ELF dependencies

Available as ScanCode Toolkit plugin.
